aboutsummaryrefslogtreecommitdiff
path: root/SRC/chbgvd.f
diff options
context:
space:
mode:
authorjulie <julielangou@users.noreply.github.com>2011-03-03 21:09:29 +0000
committerjulie <julielangou@users.noreply.github.com>2011-03-03 21:09:29 +0000
commit183a636b9a7e705b2ffa1fa358ec634f02e0997f (patch)
treeab4aea09b7f1de3837920ab9e7ce033cac211474 /SRC/chbgvd.f
parentc555ef8f8348620e259e07c0382e965f07ae45d8 (diff)
The c generated code should be better now
Diffstat (limited to 'SRC/chbgvd.f')
-rw-r--r--SRC/chbgvd.f12
1 files changed, 6 insertions, 6 deletions
diff --git a/SRC/chbgvd.f b/SRC/chbgvd.f
index db0749bc..093fad21 100644
--- a/SRC/chbgvd.f
+++ b/SRC/chbgvd.f
@@ -80,7 +80,7 @@
* if UPLO = 'L', BB(1+i-j,j) = B(i,j) for j<=i<=min(n,j+kb).
*
* On exit, the factor S from the split Cholesky factorization
-* B = S**H*S, as returned by ZPBSTF.
+* B = S**H*S, as returned by CPBSTF.
*
* LDBB (input) INTEGER
* The leading dimension of the array BB. LDBB >= KB+1.
@@ -150,7 +150,7 @@
* <= N: the algorithm failed to converge:
* i off-diagonal elements of an intermediate
* tridiagonal form did not converge to zero;
* > N: if INFO = N + i, for 1 <= i <= N, then ZPBSTF
* returned INFO = i: B is not positive definite.
* The factorization of B could not be completed and
* no eigenvalues or eigenvectors were computed.
@@ -179,8 +179,8 @@
EXTERNAL LSAME
* ..
* .. External Subroutines ..
- EXTERNAL SSTERF, XERBLA, CGEMM, ZHBGST, CHBTRD, CLACPY,
- $ ZPBSTF, CSTEDC
+ EXTERNAL SSTERF, XERBLA, CGEMM, CHBGST, CHBTRD, CLACPY,
+ $ CPBSTF, CSTEDC
* ..
* .. Executable Statements ..
*
@@ -250,7 +250,7 @@
*
* Form a split Cholesky factorization of B.
*
- CALL ZPBSTF( UPLO, N, KB, BB, LDBB, INFO )
+ CALL CPBSTF( UPLO, N, KB, BB, LDBB, INFO )
IF( INFO.NE.0 ) THEN
INFO = N + INFO
RETURN
@@ -263,7 +263,7 @@
INDWK2 = 1 + N*N
LLWK2 = LWORK - INDWK2 + 2
LLRWK = LRWORK - INDWRK + 2
- CALL ZHBGST( JOBZ, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, Z, LDZ,
+ CALL CHBGST( JOBZ, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, Z, LDZ,
$ WORK, RWORK( INDWRK ), IINFO )
*
* Reduce Hermitian band matrix to tridiagonal form.
@@ -150,7 +150,7 @@
* i off-diagonal elements of an intermediate
* tridiagonal form did not converge to zero;
-* > N: if INFO = N + i, for 1 <= i <= N, then ZPBSTF
+* > N: if INFO = N + i, for 1 <= i <= N, then CPBSTF
* returned INFO = i: B is not positive definite.
* The factorization of B could not be completed and